@@ -1,5 +1,5 @@
 import dataclasses
-from typing import Any, ClassVar, Dict, Optional
+from typing import Any, ClassVar, Dict, Iterable, Optional
 
 from dbdaora.data_sources.fallback import FallbackDataSource
 
@@ -12,7 +12,7 @@ class DictFallbackDataSource(FallbackDataSource[str]):
     key_separator: ClassVar[str] = ':'
 
     def make_key(self, *key_parts: str) -> str:
-        return self.key_separator.join(key_parts)
+        return self.key_separator.join([p for p in key_parts if p])
 
     async def get(self, key: str) -> Optional[Dict[str, Any]]:
         return self.db.get(key)
@@ -22,3 +22,6 @@ class DictFallbackDataSource(FallbackDataSource[str]):
 
     async def delete(self, key: str) -> None:
         self.db.pop(key, None)
+
+    async def query(self, key: str, **kwargs: Any) -> Iterable[Dict[str, Any]]:
+        return self.db.values()
